pub trait UserFriendlyError {
// Required methods
fn user_message(&self) -> String;
fn suggestion(&self) -> Option<String>;
}Expand description
Trait for error types that can be converted to user-friendly messages
pub trait UserFriendlyError {
// Required methods
fn user_message(&self) -> String;
fn suggestion(&self) -> Option<String>;
}Trait for error types that can be converted to user-friendly messages