ExcelHandler

Struct ExcelHandler 

pub struct ExcelHandler { /* private fields */ }
Excel file handler

Implementations

Source

impl ExcelHandler

pub fn write_with_chart( &self, path: &str, data: &[Vec<String>], chart_config: &ChartConfig, ) -> Result<()>

Write data with an embedded chart to an XLSX file

pub fn add_chart_to_data( &self, data: &[Vec<String>], chart_config: &ChartConfig, output_path: &str, ) -> Result<()>

Add a chart to existing data and write to an XLSX file

Source

impl ExcelHandler

pub fn new() -> Self

pub fn read(&self, path: &str) -> Result<String>

pub fn read_with_sheet( &self, path: &str, sheet_name: Option<&str>, ) -> Result<String>

pub fn parse_cell_reference(&self, cell: &str) -> Result<(u32, u16)>

pub fn read_range( &self, path: &str, range: &CellRange, sheet_name: Option<&str>, ) -> Result<Vec<Vec<String>>>

Read a specific range from Excel file

pub fn read_as_json( &self, path: &str, sheet_name: Option<&str>, ) -> Result<String>

Read Excel and return as JSON array

pub fn list_sheets(&self, path: &str) -> Result<Vec<String>>

Get list of sheet names in workbook (cached)

pub fn read_all_sheets( &self, path: &str, ) -> Result<HashMap<String, Vec<Vec<String>>>>

Read all sheets at once, returns map of sheet_name -> data

pub fn read_ods(&self, path: &str, sheet_name: Option<&str>) -> Result<String>

Read ODS as CSV-like string

pub fn read_ods_data( &self, path: &str, sheet_name: Option<&str>, ) -> Result<Vec<Vec<String>>>

Read ODS into Vec<Vec<String>>

pub fn list_ods_sheets(&self, path: &str) -> Result<Vec<String>>

List sheets in ODS file

pub fn read_auto( &self, path: &str, sheet_or_range: Option<&str>, ) -> Result<Vec<Vec<String>>>

Auto-detect format (XLSX/XLS/ODS) and read into Vec<Vec<String>>

Source

impl ExcelHandler

pub fn write_from_csv( &self, csv_path: &str, excel_path: &str, sheet_name: Option<&str>, ) -> Result<()>

pub fn write_styled( &self, path: &str, data: &[Vec<String>], options: &WriteOptions, ) -> Result<()>

Write data to Excel with styling options

pub fn add_sparkline_formula( &self, excel_path: &str, data_range: &str, sparkline_cell: &str, sheet_name: Option<&str>, ) -> Result<()>

Add a sparkline to an Excel file

pub fn apply_conditional_format_formula( &self, excel_path: &str, range: &str, condition: &str, true_format: &CellStyle, _false_format: Option<&CellStyle>, sheet_name: Option<&str>, ) -> Result<()>

Apply conditional formatting to an Excel file

pub fn write_range( &self, path: &str, data: &[Vec<String>], start_row: u32, start_col: u16, sheet_name: Option<&str>, ) -> Result<()>

Write data to a specific range in Excel starting at the given row and column

pub fn write_range_with_mode( &self, path: &str, data: &[Vec<String>], start_row: u32, start_col: u16, sheet_name: Option<&str>, mode: WriteMode, ) -> Result<()>

Write data to a specific range with specified write mode