pub struct HandlerRegistry { /* private fields */ }Expand description
Registry that manages file handlers by format
Implementations
Sourceimpl HandlerRegistry
impl HandlerRegistry
pub fn new() -> Self
Sourcepub fn get_reader(&self, path: &str) -> Result<Box<dyn DataReader>>
pub fn get_reader(&self, path: &str) -> Result<Box<dyn DataReader>>
Get a handler for reading a file based on its format
Sourcepub fn get_writer(&self, path: &str) -> Result<Box<dyn DataWriter>>
pub fn get_writer(&self, path: &str) -> Result<Box<dyn DataWriter>>
Get a handler for writing a file based on its format
Sourcepub fn get_handler(&self, path: &str) -> Result<Box<dyn FileHandler>>
pub fn get_handler(&self, path: &str) -> Result<Box<dyn FileHandler>>
Get a file handler (both read and write)