pub struct ExcelHandler { /* private fields */ }Expand description
Excel file handler
Implementations
Sourceimpl ExcelHandler
impl ExcelHandler
Sourcepub fn write_with_chart(
&self,
path: &str,
data: &[Vec<String>],
chart_config: &ChartConfig,
) -> Result<()>
pub fn write_with_chart( &self, path: &str, data: &[Vec<String>], chart_config: &ChartConfig, ) -> Result<()>
Write data with an embedded chart to an XLSX file
Sourcepub fn add_chart_to_data(
&self,
data: &[Vec<String>],
chart_config: &ChartConfig,
output_path: &str,
) -> Result<()>
pub fn add_chart_to_data( &self, data: &[Vec<String>], chart_config: &ChartConfig, output_path: &str, ) -> Result<()>
Add a chart to existing data and write to an XLSX file
Sourceimpl ExcelHandler
impl ExcelHandler
pub fn new() -> Self
pub fn read(&self, path: &str) -> Result<String>
pub fn read_with_sheet( &self, path: &str, sheet_name: Option<&str>, ) -> Result<String>
pub fn parse_cell_reference(&self, cell: &str) -> Result<(u32, u16)>
Sourcepub fn read_range(
&self,
path: &str,
range: &CellRange,
sheet_name: Option<&str>,
) -> Result<Vec<Vec<String>>>
pub fn read_range( &self, path: &str, range: &CellRange, sheet_name: Option<&str>, ) -> Result<Vec<Vec<String>>>
Read a specific range from Excel file
Sourcepub fn read_as_json(
&self,
path: &str,
sheet_name: Option<&str>,
) -> Result<String>
pub fn read_as_json( &self, path: &str, sheet_name: Option<&str>, ) -> Result<String>
Read Excel and return as JSON array
Sourcepub fn list_sheets(&self, path: &str) -> Result<Vec<String>>
pub fn list_sheets(&self, path: &str) -> Result<Vec<String>>
Get list of sheet names in workbook (cached)
Sourcepub fn read_all_sheets(
&self,
path: &str,
) -> Result<HashMap<String, Vec<Vec<String>>>>
pub fn read_all_sheets( &self, path: &str, ) -> Result<HashMap<String, Vec<Vec<String>>>>
Read all sheets at once, returns map of sheet_name -> data
Sourcepub fn read_ods(&self, path: &str, sheet_name: Option<&str>) -> Result<String>
pub fn read_ods(&self, path: &str, sheet_name: Option<&str>) -> Result<String>
Read ODS as CSV-like string
Sourceimpl ExcelHandler
impl ExcelHandler
pub fn write_from_csv( &self, csv_path: &str, excel_path: &str, sheet_name: Option<&str>, ) -> Result<()>
Sourcepub fn write_styled(
&self,
path: &str,
data: &[Vec<String>],
options: &WriteOptions,
) -> Result<()>
pub fn write_styled( &self, path: &str, data: &[Vec<String>], options: &WriteOptions, ) -> Result<()>
Write data to Excel with styling options
Sourcepub fn add_sparkline_formula(
&self,
excel_path: &str,
data_range: &str,
sparkline_cell: &str,
sheet_name: Option<&str>,
) -> Result<()>
pub fn add_sparkline_formula( &self, excel_path: &str, data_range: &str, sparkline_cell: &str, sheet_name: Option<&str>, ) -> Result<()>
Add a sparkline to an Excel file
Sourcepub fn apply_conditional_format_formula(
&self,
excel_path: &str,
range: &str,
condition: &str,
true_format: &CellStyle,
_false_format: Option<&CellStyle>,
sheet_name: Option<&str>,
) -> Result<()>
pub fn apply_conditional_format_formula( &self, excel_path: &str, range: &str, condition: &str, true_format: &CellStyle, _false_format: Option<&CellStyle>, sheet_name: Option<&str>, ) -> Result<()>
Apply conditional formatting to an Excel file